==> qtjambi-macextras-5.15.6-sources.jar: io/qt/macextras/QMacToolBarItem.java <==
package io.qt.macextras;


/**
 * <p>Item for QMacToolBar</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html">QMacToolBarItem</a></p>
 */
public class QMacToolBarItem extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMacToolBarItem.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#StandardItem-enum">QMacToolBarItem::StandardItem</a></p>
     */
    public enum StandardItem implements io.qt.QtEnumerator {
        NoStandardItem(0),
        Space(1),
        FlexibleSpace(2);

        private StandardItem(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static StandardItem resolve(int value) {
            switch (value) {
            case 0: return NoStandardItem;
            case 1: return Space;
            case 2: return FlexibleSpace;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#activated">QMacToolBarItem::activated()</a></p>
     */
    public final Signal0 activated = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QMacToolBarItem(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMacToolBarItem() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#QMacToolBarItem">QMacToolBarItem::QMacToolBarItem(QObject*)</a></p>
     */
    public QMacToolBarItem(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMacToolBarItem instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#icon-prop">QMacToolBarItem::icon()const</a></p>
     */
    @io.qt.QtPropertyReader(name="icon")
    @io.qt.QtUninvokable
    public final io.qt.gui.QIcon icon(){
        return icon_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QIcon icon_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#selectable-prop">QMacToolBarItem::selectable()const</a></p>
     */
    @io.qt.QtPropertyReader(name="selectable")
    @io.qt.QtUninvokable
    public final boolean selectable(){
        return selectable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean selectable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#icon-prop">QMacToolBarItem::setIcon(QIcon)</a></p>
     */
    @io.qt.QtPropertyWriter(name="icon")
    @io.qt.QtUninvokable
    public final void setIcon(io.qt.gui.QIcon icon){
        setIcon_native_cref_QIcon(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(icon));
    }
    
    @io.qt.QtUninvokable
    private native void setIcon_native_cref_QIcon(long __this__nativeId, long icon);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#selectable-prop">QMacToolBarItem::setSelectable(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="selectable")
    @io.qt.QtUninvokable
    public final void setSelectable(boolean selectable){
        setSelectable_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), selectable);
    }
    
    @io.qt.QtUninvokable
    private native void setSelectable_native_bool(long __this__nativeId, boolean selectable);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#standardItem-prop">QMacToolBarItem::setStandardItem(QMacToolBarItem::StandardItem)</a></p>
     */
    @io.qt.QtPropertyWriter(name="standardItem")
    @io.qt.QtUninvokable
    public final void setStandardItem(io.qt.macextras.QMacToolBarItem.StandardItem standardItem){
        setStandardItem_native_QMacToolBarItem_StandardItem(QtJambi_LibraryUtilities.internal.nativeId(this), standardItem.value());
    }
    
    @io.qt.QtUninvokable
    private native void setStandardItem_native_QMacToolBarItem_StandardItem(long __this__nativeId, int standardItem);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#text-prop">QMacToolBarItem::setText(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="text")
    @io.qt.QtUninvokable
    public final void setText(java.lang.String text){
        setText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @io.qt.QtUninvokable
    private native void setText_native_cref_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#standardItem-prop">QMacToolBarItem::standardItem()const</a></p>
     */
    @io.qt.QtPropertyReader(name="standardItem")
    @io.qt.QtUninvokable
    public final io.qt.macextras.QMacToolBarItem.StandardItem standardItem(){
        return io.qt.macextras.QMacToolBarItem.StandardItem.resolve(standardItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int standardItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#text-prop">QMacToolBarItem::text()const</a></p>
     */
    @io.qt.QtPropertyReader(name="text")
    @io.qt.QtUninvokable
    public final java.lang.String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QMacToolBarItem(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QMacToolBarItem(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QMacToolBarItem instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-macextras-5.15.14-sources.jar: io/qt/macextras/QMacToolBarItem.java <==
package io.qt.macextras;

import io.qt.*;


/**
 * <p>Item for QMacToolBar</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html">QMacToolBarItem</a></p>
 */
public class QMacToolBarItem extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMacToolBarItem.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#StandardItem-enum">QMacToolBarItem::StandardItem</a></p>
     */
    @QtUnlistedEnum
    public enum StandardItem implements QtEnumerator {
        NoStandardItem(0),
        Space(1),
        FlexibleSpace(2);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private StandardItem(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static StandardItem resolve(int value) {
            switch (value) {
            case 0: return NoStandardItem;
            case 1: return Space;
            case 2: return FlexibleSpace;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#activated">QMacToolBarItem::activated()</a></p>
     */
    public final @NonNull Signal0 activated = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QMacToolBarItem() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#QMacToolBarItem">QMacToolBarItem::QMacToolBarItem(QObject*)</a></p>
     */
    public QMacToolBarItem(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMacToolBarItem instance, io.qt.core.QObject parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #icon()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.gui.@NonNull QIcon getIcon() {
        return icon();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#icon-prop">QMacToolBarItem::icon()const</a></p>
     */
    @QtPropertyReader(name="icon")
    @QtUninvokable
    public final io.qt.gui.@NonNull QIcon icon(){
        return icon_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.gui.QIcon icon_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #selectable()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getSelectable() {
        return selectable();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#selectable-prop">QMacToolBarItem::selectable()const</a></p>
     */
    @QtPropertyReader(name="selectable")
    @QtUninvokable
    public final boolean selectable(){
        return selectable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean selectable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#icon-prop">QMacToolBarItem::setIcon(QIcon)</a></p>
     */
    @QtPropertyWriter(name="icon")
    @QtUninvokable
    public final void setIcon(io.qt.gui.@NonNull QIcon icon){
        setIcon_native_cref_QIcon(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(icon));
    }
    
    @QtUninvokable
    private native void setIcon_native_cref_QIcon(long __this__nativeId, long icon);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#selectable-prop">QMacToolBarItem::setSelectable(bool)</a></p>
     */
    @QtPropertyWriter(name="selectable")
    @QtUninvokable
    public final void setSelectable(boolean selectable){
        setSelectable_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), selectable);
    }
    
    @QtUninvokable
    private native void setSelectable_native_bool(long __this__nativeId, boolean selectable);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#standardItem-prop">QMacToolBarItem::setStandardItem(QMacToolBarItem::StandardItem)</a></p>
     */
    @QtPropertyWriter(name="standardItem")
    @QtUninvokable
    public final void setStandardItem(io.qt.macextras.QMacToolBarItem.@NonNull StandardItem standardItem){
        setStandardItem_native_QMacToolBarItem_StandardItem(QtJambi_LibraryUtilities.internal.nativeId(this), standardItem.value());
    }
    
    @QtUninvokable
    private native void setStandardItem_native_QMacToolBarItem_StandardItem(long __this__nativeId, int standardItem);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#text-prop">QMacToolBarItem::setText(QString)</a></p>
     */
    @QtPropertyWriter(name="text")
    @QtUninvokable
    public final void setText(java.lang.@NonNull String text){
        setText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @QtUninvokable
    private native void setText_native_cref_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #standardItem()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.macextras.QMacToolBarItem.@NonNull StandardItem getStandardItem() {
        return standardItem();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#standardItem-prop">QMacToolBarItem::standardItem()const</a></p>
     */
    @QtPropertyReader(name="standardItem")
    @QtUninvokable
    public final io.qt.macextras.QMacToolBarItem.@NonNull StandardItem standardItem(){
        return io.qt.macextras.QMacToolBarItem.StandardItem.resolve(standardItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int standardItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #text()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getText() {
        return text();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qmactoolbaritem.html#text-prop">QMacToolBarItem::text()const</a></p>
     */
    @QtPropertyReader(name="text")
    @QtUninvokable
    public final java.lang.@NonNull String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QMacToolBarItem(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QMacToolBarItem(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QMacToolBarItem instance, QDeclarativeConstructor constructor);
    
}
